@@ -2,7 +2,8 @@
 # Copyright (c) 2015 Fabian Barkhau <fabian.barkhau@gmail.com>
 # License: MIT (see LICENSE file)
 
-from apigen import (
+
+from . apigen import (
     VarargsFound, KeywordsFound, # exceptions
     command, # decorator
     Definition, # API base class
